==> QupZilla-2.0.1.tar.xz: QupZilla-2.0.1/src/plugins/StatusBarIcons/translations/ar_SA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar_SA" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>بدّل إعدادات تحميل الصور لكل موقع على حدة أو لكل المواقع معاً</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>إعدادات الصفحة الحالية</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>امنع تحميل الصور (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>اسمح بتحميل الصور (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>الإعدادات العامّة</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>اسمح بتحميل الصور</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>بدّل إعدادات جافاسكربت لكل موقع على حدة أو لكل المواقع معاً</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>إعدادات الصفحة الحالية</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>امنع جافاسكربت (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>اسمح بجافاسكربت (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>الإعدادات العامّة</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>أدِر إعدادات جافاسكربت</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>ضبط الخادوم الوكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>اختر خادوماً وكيلاً</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>فارغ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>أدر الخواديم الوكيلة</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>يُظهر حالة الشبكة ويدير الخادوم الوكيل&lt;br/&gt;&lt;br/&gt;&lt;b&gt;الشبكة:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;الخادم الوكيل:&lt;/b&gt;&lt;br/&gt;%2 </translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>متّصل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>غير متّصل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>الخادوم الوكيل الذي يستخدمه نظام التشغيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>بلا خادوم وكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>حَدّده المستخدم</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>إدارة الخواديم الوكيلة</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>اختر خادوماً وكيلاً:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>أضف خادوماً وكيلاً</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>احذف الخادوم الوكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>لا خواديم وكيلة. يمكنك إضافة واحد بالنقر على زر .&lt;b&gt;أضف&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>عليك أن تحفظ كل التغييرات بالنقر على زر &lt;b&gt;احفظ&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>اسم الخادوم الوكيل:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>احذف الخادوم الوكيل الحاليّ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>النموذج</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>المنفذ:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>كلمة المرور:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>رموز شريط الحالة</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;رموز شريط الحالة&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>ستُعرض هذه الرموز في شريط الحالة:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>رمز الصور</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>رمز جافاسكربت</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>رمز الشبكة</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>أداة التقريب</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>التقريب: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.6.tar.xz: QupZilla-2.2.6/src/plugins/StatusBarIcons/translations/ar_SA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar_SA" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="33"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>بدّل إعدادات تحميل الصور لكل موقع على حدة أو لكل المواقع معاً</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="57"/>
        <source>Current Page Settings</source>
        <translation>إعدادات الصفحة الحالية</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Disable loading images (temporarily)</source>
        <translation>امنع تحميل الصور (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Enable loading images (temporarily)</source>
        <translation>اسمح بتحميل الصور (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="67"/>
        <source>Global Settings</source>
        <translation>الإعدادات العامّة</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="69"/>
        <source>Automatically load images</source>
        <translation>اسمح بتحميل الصور</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>بدّل إعدادات جافاسكربت لكل موقع على حدة أو لكل المواقع معاً</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Current Page Settings</source>
        <translation>إعدادات الصفحة الحالية</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>امنع جافاسكربت (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="57"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>اسمح بجافاسكربت (مؤقتاً)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>الإعدادات العامّة</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="67"/>
        <source>Manage JavaScript settings</source>
        <translation>أدِر إعدادات جافاسكربت</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="65"/>
        <source>Proxy Configuration</source>
        <translation>ضبط الخادوم الوكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="67"/>
        <source>Select proxy</source>
        <translation>اختر خادوماً وكيلاً</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="81"/>
        <source>Empty</source>
        <translation>فارغ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="85"/>
        <source>Manage proxies</source>
        <translation>أدر الخواديم الوكيلة</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="98"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>يُظهر حالة الشبكة ويدير الخادوم الوكيل&lt;br/&gt;&lt;br/&gt;&lt;b&gt;الشبكة:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;الخادم الوكيل:&lt;/b&gt;&lt;br/&gt;%2 </translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Connected</source>
        <translation>متّصل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Offline</source>
        <translation>غير متّصل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="109"/>
        <source>System proxy</source>
        <translation>الخادوم الوكيل الذي يستخدمه نظام التشغيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="113"/>
        <source>No proxy</source>
        <translation>بلا خادوم وكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="117"/>
        <source>User defined</source>
        <translation>حَدّده المستخدم</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>إدارة الخواديم الوكيلة</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>اختر خادوماً وكيلاً:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>أضف خادوماً وكيلاً</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>احذف الخادوم الوكيل</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>لا خواديم وكيلة. يمكنك إضافة واحد بالنقر على زر .&lt;b&gt;أضف&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>عليك أن تحفظ كل التغييرات بالنقر على زر &lt;b&gt;احفظ&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>اسم الخادوم الوكيل:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>احذف الخادوم الوكيل الحاليّ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>أتريد حقاً أن تحذف الخادوم الوكيل الحاليّ؟</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>النموذج</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>المنفذ:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>كلمة المرور:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>ضبط وكيل الن&amp;ظام</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>ضبط ي&amp;دوي</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>رموز شريط الحالة</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;رموز شريط الحالة&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>ستُعرض هذه الرموز في شريط الحالة:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>رمز الصور</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>رمز جافاسكربت</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>رمز الشبكة</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>أداة التقريب</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="48"/>
        <source>Zoom: %1%</source>
        <translation>التقريب: %1%</translation>
    </message>
</context>
</TS>
